<?php
/* Copyright (C) 2015		Charles-fr BENKE 			<charles.fr@benke.fr>
 * Copyright (C) 2016		Philippe SAGOT (Philazerty)	<courrier@mon-dolibarr.fr>
 * Copyright (C) 2017	    Laurent DINCLAUX (loxK)   <laurent@gecka.nc>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *        \file       htdocs/geckanewcaledonia/admin/setup.php
 *        \ingroup    geckanewcaledonia
 *        \brief      Page to setup the module geckanewcaledonia
 */

// Dolibarr environment
//uggly hack to work arround module being symlink to a dolibarr install
$_dir = dirname(dirname(dirname($_SERVER['SCRIPT_FILENAME'])));

$res = 0;
if (! $res && file_exists($_dir . "/main.inc.php")) {
    $res = @include($_dir . "/main.inc.php");
}        // For root directory
if (! $res && file_exists($_dir . "/../main.inc.php")) {
    $res = @include($_dir . "/../main.inc.php");
}    // For "custom" directory

require_once DOL_DOCUMENT_ROOT . '/core/lib/admin.lib.php';
dol_include_once('/geckanewcaledonia/core/lib/main.lib.php');

$langs->load("admin");
$langs->load("geckanewcaledonia@geckanewcaledonia");

if (! $user->admin) {
    accessforbidden();
}

$action = GETPOST('action', 'alpha');

/*
 * Actions
 */
if ($action == 'dumpTAXdata') {
    $replace = GETPOST('replace', 'int');
    $res         = geckanewcaledonia_admin_dump_tax_data($replace);
    if (! $res > 0) {
        $error ++;
    }

    if (! $error) {
        setEventMessages($langs->trans("DataSaved"), null, 'mesgs');
    } else {
        setEventMessages($langs->trans("Error"), null, 'mesgs');
    }
}

if ($action == 'dumpFJdata') {
    $replace = GETPOST('replace', 'int');
    $res         = geckanewcaledonia_admin_dump_legal_form($replace);
    if (! $res > 0) {
        $error ++;
    }

    if (! $error) {
        setEventMessages($langs->trans("DataSaved"), null, 'mesgs');
    } else {
        setEventMessages($langs->trans("Error"), null, 'mesgs');
    }
}

if ($action == 'dumpLangs') {
    $replace = GETPOST('replace', 'int');
    $res         = geckanewcaledonia_admin_dump_langs($replace);
    if (! $res > 0) {
        $error ++;
    }

    if (! $error) {
        setEventMessages($langs->trans("DataSaved"), null, 'mesgs');
    } else {
        setEventMessages($langs->trans("Error"), null, 'mesgs');
    }
}


/*
 * View
 */
llxHeader('', $langs->trans("GeckaNewCaledonia"), $help_url);

$form = new Form($db);

$linkback = '<a href="' . DOL_URL_ROOT . '/admin/modules.php">' . $langs->trans("BackToModuleList") . '</a>';
print load_fiche_titre($langs->trans("DictionarySetup"), $linkback, 'title_setup');

$head = geckanewcaledonia_admin_prepare_head();
dol_fiche_head($head, 'setup-dictionaries', $langs->trans("GeckaNewCaledonia"), 0, 'list');


print '<table class="noborder" width="100%" id="dictDataDump">';

print '<tr class="liste_titre">';
print '<td colspan="2">' . $langs->trans('GKNCDictionariesData') . '</td>';
print "</tr>\n";

print '<tr class="value">';
print '<td>' . 'Taxes applicables en Nouvelle-Calédonie' . '<br>';
print '<small>' . 'Ajoutera la TGC et la TSS pour la Nouvelle-Calédonie dans le dictionnaire des taxe' . '</small></td>';
// Value
print '<td align="right">';
print '<form action="' . $_SERVER["PHP_SELF"] . '" class="dumpData" method="post">';
print '<input type="submit" value="Ajouter" class="button">';
print '<br>';
print '<label><input type="checkbox" name="replace" value="1"> Remplacer</label>';
print '<input type="hidden" name="action" value="dumpTAXdata">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '</form>';
print '</td>';
print '</tr>';

print '<tr class="value">';
print '<td>' . 'Formes juridiques pour la Nouvelle-Calédonie' . '<br>';
print '<small>' . 'Ajoutera les formes juridiques pour la Nouvelle-Calédonie en dupliquant les formes juridiques françaises' . '</small></td>';
// Value
print '<td align="right">';
print '<form action="' . $_SERVER["PHP_SELF"] . '" class="dumpData" method="post">';
print '<input type="submit" value="Ajouter" class="button ">';
print '<br>';
print '<label><input type="checkbox" name="replace" value="1"> Remplacer</label>';
print '<input type="hidden" name="action" value="dumpFJdata">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '</form>';
print '</td>';
print '</tr>';

print '<tr class="value">';
print '<td>' . 'Surcharge des traductions' . '<br>';
print '<small>' . 'Surcharge des traductions pour remplacer la TSS et/ou TVA par la TGC' . '</small></td>';
// Value
print '<td align="right">';
print '<form action="' . $_SERVER["PHP_SELF"] . '" class="dumpData" method="post">';
print '<input type="submit" value="Ajouter" class="button ">';
print '<br>';
print '<label><input type="checkbox" name="replace" value="1"> Remplacer</label>';
print '<input type="hidden" name="action" value="dumpLangs">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '</form>';
print '</td>';
print '</tr>';

print '</table>';

dol_fiche_end();

print '<br>';
print '<br>';

llxFooter();
$db->close();
